@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-06-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-06-22'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,11 @@ use warnings;
 
 our $scenario = {
     summary => 'Benchmark Log::ger logging speed with the default/null output',
+    modules => {
+        'Log::ger' => {version=>'0.002'},
+        'Log::Any' => {},
+        'Log::Fast' => {},
+    },
     participants => [
         {
             name => 'Log::ger-1mil_log_trace',
@@ -23,6 +28,11 @@ our $scenario = {
             perl_cmdline_template => ['-MLog::ger::OptAway', '-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
         },
 
+        {
+            name => 'Log::Fast-1mil_DEBUG',
+            perl_cmdline_template => ['-MLog::Fast', '-e', '$LOG = Log::Fast->global; $LOG->level("INFO"); for(1..1_000_000) { $LOG->DEBUG(q()) }'],
+        },
+
         {
             name => 'Log::Any-no_adapter-1mil_log_trace',
             perl_cmdline_template => ['-MLog::Any', '-e', 'my $log = Log::Any->get_logger; for(1..1_000_000) { $log->trace(q[]) }'],
@@ -58,7 +68,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-21.
+This document describes version 0.003 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-22.
 
 =head1 SYNOPSIS
 
@@ -72,6 +82,16 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
 
+=head1 BENCHMARKED MODULES
+
+Version numbers shown below are the versions used when running the sample benchmark.
+
+L<Log::Any> 1.045
+
+L<Log::Fast> v2.0.0
+
+L<Log::ger> 0.004
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -100,6 +120,14 @@ Command line:
 
 
 
+=item * Log::Fast-1mil_DEBUG (command)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::Fast -e $LOG = Log::Fast->global; $LOG->level("INFO"); for(1..1_000_000) { $LOG->DEBUG(q()) }
+
+
+
 =item * Log::Any-no_adapter-1mil_log_trace (command)
 
 Command line:
@@ -136,22 +164,23 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
  #table1#
- +-------------------------------------------+-----------+-----------+------------+---------+---------+
- | participant                               | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +-------------------------------------------+-----------+-----------+------------+---------+---------+
- | Log::Any-null_adapter-1mil_log_trace      |       1.6 |       610 |        1   | 0.0035  |       7 |
- | Log::Any-null_adapter-1mil_is_trace       |       2.5 |       400 |        1.5 | 0.00071 |       6 |
- | Log::Any-no_adapter-1mil_is_trace         |       2.5 |       400 |        1.5 | 0.00041 |       6 |
- | Log::Any-no_adapter-1mil_log_trace        |       6.4 |       160 |        3.9 | 0.00094 |       7 |
- | Log::ger-1mil_log_is_trace                |       8.5 |       120 |        5.2 | 0.00013 |       6 |
- | Log::ger-1mil_log_trace                   |       9.9 |       100 |        6   | 0.00073 |       6 |
- | Log::ger+Log::ger::OptAway-1mil_log_trace |      25   |        40 |       15   | 0.00012 |       6 |
- +-------------------------------------------+-----------+-----------+------------+---------+---------+
+ +-------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                               | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | Log::Any-null_adapter-1mil_log_trace      |       2.5 |     410   |       1    |   0.00061 |       6 |
+ | Log::Any-no_adapter-1mil_is_trace         |       4.1 |     240   |       1.7  |   0.0015  |       6 |
+ | Log::Any-null_adapter-1mil_is_trace       |       4.1 |     240   |       1.7  |   0.00093 |       6 |
+ | Log::Any-no_adapter-1mil_log_trace        |      11.2 |      89.5 |       4.54 | 7.2e-05   |       6 |
+ | Log::Fast-1mil_DEBUG                      |      11   |      88   |       4.6  |   0.00037 |       6 |
+ | Log::ger-1mil_log_is_trace                |      16.9 |      59.3 |       6.85 | 1.7e-05   |       9 |
+ | Log::ger-1mil_log_trace                   |      18   |      55   |       7.3  | 8.8e-05   |       6 |
+ | Log::ger+Log::ger::OptAway-1mil_log_trace |      39   |      25   |      16    |   0.00012 |       6 |
+ +-------------------------------------------+-----------+-----------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
