@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::Startup;
 
-our $DATE = '2017-06-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-06-22'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,7 +40,7 @@ Bencher::Scenario::LogGer::Startup
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::LogGer::Startup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-21.
+This document describes version 0.003 of Bencher::Scenario::LogGer::Startup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-22.
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::Any> 1.049
+L<Log::Any> 1.045
 
 L<Log::Any::Adapter::Screen> 0.13
 
@@ -120,7 +120,7 @@ L<Log::Any::Adapter::Screen>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with C<< bencher -m LogGer::Startup --include-path archive/Log-Any-0.15/lib --multimodver Log::Any >>:
 
@@ -128,30 +128,30 @@ Benchmark with C<< bencher -m LogGer::Startup --include-path archive/Log-Any-0.1
  +----------------------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                                  | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +----------------------------------------------+--------+-----------+-----------+------------+---------+---------+
- | use Log::ger + use Log::ger::OptAway         |        |        66 |      15   |        1   | 5.9e-05 |      20 |
- | use Log::Any + use Log::Any::Adapter::Screen |        |        77 |      13   |        1.2 | 4.6e-05 |      20 |
- | use Log::Any                                 | 1.049  |        91 |      11   |        1.4 | 7.4e-05 |      20 |
- | use Log::ger + use Log::ger::Output::Screen  |        |       150 |       6.8 |        2.2 | 2.2e-05 |      20 |
- | use Log::Any                                 | 0.15   |       210 |       4.8 |        3.2 | 1.1e-05 |      21 |
- | use Log::ger                                 |        |       340 |       2.9 |        5.2 | 2.7e-05 |      20 |
- | use Log::ger ()                              |        |       350 |       2.8 |        5.4 | 2.5e-05 |      20 |
- | baseline                                     |        |       600 |       2   |        9   | 1.7e-05 |      20 |
+ | use Log::ger + use Log::ger::OptAway         |        |       110 |       9.3 |        1   | 1.8e-05 |      20 |
+ | use Log::Any + use Log::Any::Adapter::Screen |        |       120 |       8   |        1.2 | 3.3e-05 |      20 |
+ | use Log::Any                                 | 1.045  |       150 |       6.6 |        1.4 | 1.5e-05 |      22 |
+ | use Log::ger + use Log::ger::Output::Screen  |        |       240 |       4.1 |        2.3 | 2.1e-05 |      20 |
+ | use Log::Any                                 | 0.15   |       330 |       3   |        3.1 | 1.5e-05 |      20 |
+ | use Log::ger                                 |        |       550 |       1.8 |        5.1 | 1.3e-05 |      21 |
+ | use Log::ger ()                              |        |       590 |       1.7 |        5.5 | 5.9e-06 |      21 |
+ | baseline                                     |        |       880 |       1.1 |        8.2 | 4.8e-06 |      21 |
  +----------------------------------------------+--------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::Startup --module-startup >>):
 
  #table2#
- +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | participant               | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | Log::Any::Adapter::Screen | 1.5                          | 5.1                | 21             |      18   |                   12.3 |        1   |   0.00014 |      20 |
- | Log::Any                  | 1.1                          | 4.5                | 20             |      15   |                    9.3 |        1.2 |   0.00011 |      20 |
- | Log::ger::OptAway         | 0.95                         | 4.4                | 20             |      11   |                    5.3 |        1.7 |   6e-05   |      20 |
- | Log::ger::Output::Screen  | 1.1                          | 4.5                | 20             |      10   |                    4.3 |        1.7 | 3.6e-05   |      22 |
- | Log::ger                  | 0.95                         | 4.4                | 20             |       7.5 |                    1.8 |        2.4 | 4.4e-05   |      21 |
- | perl -e1 (baseline)       | 0.82                         | 4.3                | 20             |       5.7 |                    0   |        3.1 | 3.1e-05   |      20 |
- +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant               | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Log::Any::Adapter::Screen | 1.5                          | 4.9                | 21             |       9.5 |                    7   |        1   | 3.8e-05 |      20 |
+ | Log::Any                  | 1.1                          | 4.4                | 20             |       8.2 |                    5.7 |        1.2 | 1.2e-05 |      20 |
+ | Log::ger::Output::Screen  | 1.1                          | 4.3                | 20             |       5.3 |                    2.8 |        1.8 | 9.6e-06 |      20 |
+ | Log::ger::OptAway         | 0.95                         | 4.3                | 20             |       5.2 |                    2.7 |        1.8 | 1.4e-05 |      21 |
+ | Log::ger                  | 0.95                         | 4.2                | 20             |       3.3 |                    0.8 |        2.9 | 1.6e-05 |      20 |
+ | perl -e1 (baseline)       | 0.82                         | 4.1                | 20             |       2.5 |                    0   |        3.8 | 7.6e-06 |      20 |
+ +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
